Module: Google::Apis::WorkflowsV1beta
- Defined in:
- lib/google/apis/workflows_v1beta.rb,
lib/google/apis/workflows_v1beta/classes.rb,
lib/google/apis/workflows_v1beta/service.rb,
lib/google/apis/workflows_v1beta/gem_version.rb,
lib/google/apis/workflows_v1beta/representations.rb
Overview
Workflows API
Manage workflow definitions. To execute workflows and manage executions, see the Workflows Executions API.
Defined Under Namespace
Classes: Empty, ListLocationsResponse, ListOperationsResponse, ListWorkflowsResponse, Location, Operation, OperationMetadata, Status, Workflow, WorkflowsService
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-workflows_v1beta gem
"0.32.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20251203"- VERSION =
Version of the Workflows API this client connects to. This is NOT the gem version.
'V1beta'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'