Class: Google::Apis::WorkflowsV1beta::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::WorkflowsV1beta::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workflows_v1beta/classes.rb,
lib/google/apis/workflows_v1beta/representations.rb,
lib/google/apis/workflows_v1beta/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
API version used to start the operation.
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#target ⇒ String
Server-defined resource path for the target of the operation.
-
#verb ⇒ String
Name of the verb executed by the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
270 271 272 |
# File 'lib/google/apis/workflows_v1beta/classes.rb', line 270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
API version used to start the operation.
Corresponds to the JSON property apiVersion
248 249 250 |
# File 'lib/google/apis/workflows_v1beta/classes.rb', line 248 def api_version @api_version end |
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
253 254 255 |
# File 'lib/google/apis/workflows_v1beta/classes.rb', line 253 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
258 259 260 |
# File 'lib/google/apis/workflows_v1beta/classes.rb', line 258 def end_time @end_time end |
#target ⇒ String
Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
263 264 265 |
# File 'lib/google/apis/workflows_v1beta/classes.rb', line 263 def target @target end |
#verb ⇒ String
Name of the verb executed by the operation.
Corresponds to the JSON property verb
268 269 270 |
# File 'lib/google/apis/workflows_v1beta/classes.rb', line 268 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
275 276 277 278 279 280 281 |
# File 'lib/google/apis/workflows_v1beta/classes.rb', line 275 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |