Class: Google::Apis::WorkflowsV1beta::WorkflowsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::WorkflowsV1beta::WorkflowsService
- Defined in:
- lib/google/apis/workflows_v1beta/service.rb
Overview
Workflows API
Manage workflow definitions. To execute workflows and manage executions, see the Workflows Executions API.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://workflows.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_workflow(parent, workflow_object = nil, workflow_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Operation
Creates a new workflow.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Empty
Deletes a long-running operation.
-
#delete_project_location_workflow(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Operation
Deletes a workflow with the specified name.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Location
Gets information about a location.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_workflow(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Workflow
Gets details of a single Workflow.
-
#initialize ⇒ WorkflowsService
constructor
A new instance of WorkflowsService.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_workflows(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::ListWorkflowsResponse
Lists Workflows in a given project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_workflow(name, workflow_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Operation
Updates an existing workflow.
Constructor Details
#initialize ⇒ WorkflowsService
Returns a new instance of WorkflowsService.
48 49 50 51 52 53 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-workflows_v1beta', client_version: Google::Apis::WorkflowsV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#create_project_location_workflow(parent, workflow_object = nil, workflow_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Operation
Creates a new workflow. If a workflow with the specified name already exists in the specified project and location, the long running operation will return ALREADY_EXISTS error.
284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 284 def create_project_location_workflow(parent, workflow_object = nil, workflow_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/workflows', ) command.request_representation = Google::Apis::WorkflowsV1beta::Workflow::Representation command.request_object = workflow_object command.response_representation = Google::Apis::WorkflowsV1beta::Operation::Representation command.response_class = Google::Apis::WorkflowsV1beta::Operation command.params['parent'] = parent unless parent.nil? command.query['workflowId'] = workflow_id unless workflow_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
164 165 166 167 168 169 170 171 172 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 164 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkflowsV1beta::Empty::Representation command.response_class = Google::Apis::WorkflowsV1beta::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_workflow(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Operation
Deletes a workflow with the specified name. This method also cancels and deletes all running executions of the workflow.
319 320 321 322 323 324 325 326 327 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 319 def delete_project_location_workflow(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkflowsV1beta::Operation::Representation command.response_class = Google::Apis::WorkflowsV1beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkflowsV1beta::Location::Representation command.response_class = Google::Apis::WorkflowsV1beta::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
195 196 197 198 199 200 201 202 203 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 195 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkflowsV1beta::Operation::Representation command.response_class = Google::Apis::WorkflowsV1beta::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workflow(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Workflow
Gets details of a single Workflow.
350 351 352 353 354 355 356 357 358 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 350 def get_project_location_workflow(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::WorkflowsV1beta::Workflow::Representation command.response_class = Google::Apis::WorkflowsV1beta::Workflow command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 240 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}/operations', ) command.response_representation = Google::Apis::WorkflowsV1beta::ListOperationsResponse::Representation command.response_class = Google::Apis::WorkflowsV1beta::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workflows(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::ListWorkflowsResponse
Lists Workflows in a given project and location. The default order is not specified.
398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 398 def list_project_location_workflows(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/workflows', ) command.response_representation = Google::Apis::WorkflowsV1beta::ListWorkflowsResponse::Representation command.response_class = Google::Apis::WorkflowsV1beta::ListWorkflowsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 127 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}/locations', ) command.response_representation = Google::Apis::WorkflowsV1beta::ListLocationsResponse::Representation command.response_class = Google::Apis::WorkflowsV1beta::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_workflow(name, workflow_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkflowsV1beta::Operation
Updates an existing workflow. Running this method has no impact on already running executions of the workflow. A new revision of the workflow may be created as a result of a successful update operation. In that case, such revision will be used in new workflow executions.
440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/google/apis/workflows_v1beta/service.rb', line 440 def patch_project_location_workflow(name, workflow_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::WorkflowsV1beta::Workflow::Representation command.request_object = workflow_object command.response_representation = Google::Apis::WorkflowsV1beta::Operation::Representation command.response_class = Google::Apis::WorkflowsV1beta::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |